/* lab3 radar
 
 * 
 * based on the example "Read ultrasonic distance Sensor" and "Stepper motor controller"
 *
 * uses SRF02 library from grapelabs, http://www.grapelabs.de
 * uses metro library, http://www.arduino.cc/playground/Code/Metro
 *
 * remove red jumper near built-in poti to use I2C bus
 * connect plug with three wires on A5 and plug with one wire on A4
 *
 
 * SensorAktor Workshop
 * Lab3 2008
 * Kunsthochschule fuer Medien Koeln
 * Academy of Media Arts Cologne
 * http://interface.khm.de
 
 * pin mapping SensorAktor Shield (import <SensorAktor.h> to get already defined mapping)
 *
 * analog inputs: a0 = pin0, a1 = pin1, a2 = pin2, a3 = pin3, a4 = pin4, a5 = pin5
 * built-in poti: poti = pin5
 * amplified input: mic = pin0
 * switches: s1 = pin1, s2 = pin2, s3 = pin3
 * leds: led1 = pin3, led2 = pin5, led3 = pin6
 * power outs: out1 = pin3, out2 = pin5, out3 = pin6
 * motor outs: motor1_1 = pin11, motor1_2 = pin12, motor2_1 = pin13, motor2_2 = pin8
 * motor pwms: pwmMotor1 = pin9, pwmMotor2 = pin10
 * servo outs: servo1 = pin2, servo2 = pin4, servo3 = pin7
 
 */


// import sensor aktor library for pin mapping
#include <SensorAktor.h>

// import wire library to use I2C bus
#include "Wire.h"

// import SRF02 library
#include "SRF02.h"
//  ultrasonic distance sensor
#include "WProgram.h"
void setup();
void loop();
SRF02 distanceSensor(0x70, SRF02_CENTIMETERS);

// import stepper library
#include <StepperL293.h>
// stepper
StepperL293 myStepper;
// total steps
int totalSteps = 0;
int directionSteps = 1;



// import metro library (for serial output)
#include <Metro.h>
// radar metro
Metro radarMetro = Metro(100);

void setup()
{

  // start serial communication (for printing to serial port)
  Serial.begin(9600);

  // start I2C communication
  Wire.begin();

  // set interval for ultrasonic distance sensor
  SRF02::setInterval(100);

  // attach pins to stepper (motor pin1, motor pin2, motor pin3, motor pin4, number of steps of motor)
  myStepper.attach(motor1_1, motor1_2, motor2_1, motor2_2, 48);

  // set mode (0 = half step moede, 1 = full step mode)
  myStepper.setMode(0);

  // set power (value between 0 and 100)
  myStepper.setPower(100);

  // set speed (values between 1 and 100)
  myStepper.setSpeed(10);


}

void loop()
{

  // update sensor data
  SRF02::update();

  // check radar metro
  if(radarMetro.check() == 1){

    // check direction steps (0=left, 1=right)
    if(directionSteps == 1){
      // counter steps
      totalSteps++;
      // 95 steps is one full rotation in half step mode
      if(totalSteps >= 95){
        // turn left
        directionSteps = 0;
      }
    }
    else{
      // counter steps
      totalSteps--;
      if(totalSteps <= 0){
        // turn right
        directionSteps = 1;
      }

    }

    // set new step
    myStepper.setStep(totalSteps);

    /* build message for serial port (to receive data in processing)
     format to send = recectStep, space, sensorValue, space, linebreak
     */
    Serial.print( totalSteps);
    Serial.print(32,BYTE);
    Serial.print(distanceSensor.read());
    //Serial.print(analogRead(a0));
    Serial.print(32,BYTE);
    Serial.println();

  }

  // drive stepper
  myStepper.drive();

}

int main(void)
{
	init();

	setup();
    
	for (;;)
		loop();
        
	return 0;
}

